if __name__ == '__main__':
    from ._main import main
    code = main()
    exit(code)
